﻿using System;
using System.Collections.ObjectModel;
using System.IO;

using ThinkGeo.MapSuite.Core;
using System.Globalization;
using System.Drawing;

namespace RenderUsa
{
    public class UsaRenderers
    {
        //private MapEngine mapEngine;
        private string dataFolder;
        //private GeoSolidBrush backgroundBrush;
        private Collection<Layer> staticLayers;
        private Collection<Layer> dynamicLayers;

        public UsaRenderers(string dataFolder)
        {
            this.dataFolder = dataFolder;
            //mapEngine = new MapEngine();
            staticLayers = new Collection<Layer>();
            dynamicLayers = new Collection<Layer>();

            //backgroundBrush = new GeoSolidBrush(GeoColor.SimpleColors.Transparent);
        }

        public RectangleShape DefaultExtent
        {
            get
            {
                return new RectangleShape(-125, 50, -66, 23);
            }
        }

        public void LoadLayers(Collection<Layer> staticLayers, Collection<Layer> dynamicLayers)
        {
            this.staticLayers = staticLayers;
            this.dynamicLayers = dynamicLayers;

            //  Add all of our vector layers
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\canada.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\mexico.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cntry02_minusna.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\states.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\counties.shp", ShapeFileReadWriteMode.ReadOnly));
            LoadStateSymbolLayers("ctycu");
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\urban_dtl.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandbia.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandfs.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandfws.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlanddod.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\interiorlakesgen.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\interiorlakes.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\lakes.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\countrylakes.shp", ShapeFileReadWriteMode.ReadOnly));
            LoadStateSymbolLayers("wat");
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandnps.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandnpsclip.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\swamps.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\rivers.shp", ShapeFileReadWriteMode.ReadOnly));
            LoadLowerRoadSymbolLayers();
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\rail100k.shp", ShapeFileReadWriteMode.ReadOnly));
            LoadHighRoadSymbolLayers();
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\ushigh1.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\HighwayNetwork2_1b.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\HighwayNetwork2_2.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\highwaynetwork1_50m.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\highwaynetwork1_10m.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\HighwayNetwork1.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\internationalborders.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\stateborders.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\primaryborders.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_a.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\countrycities.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_b.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_c2.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderSymblLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\airports.shp", ShapeFileReadWriteMode.ReadOnly));

            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandbia.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandfs.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandfws.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlanddod.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\lakes.shp", ShapeFileReadWriteMode.ReadOnly));
            LoadStateLabelLayers("wat");
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\fedlandnpsclip.shp", ShapeFileReadWriteMode.ReadOnly));
            LoadLowerRoadLabelLayers();
            LoadHighRoadLabelLayers();
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\ushigh1.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\HighwayNetwork2_1b.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\HighwayNetwork2_2.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\highwaynetwork1_50m.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\highwaynetwork1_10m.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\HighwayNetwork1.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_a.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\countrycities.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_b.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_c2.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\statetext.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_c.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_d.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cities_e.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\airports.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\countrytext.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\cntry02_minusna.shp", ShapeFileReadWriteMode.ReadOnly));
            RenderLabelLayer(new ShapeFileFeatureLayer(dataFolder + @"\USA\seatext.shp", ShapeFileReadWriteMode.ReadOnly));     
        }

        #region MainRenderAPIs

        private void LoadStateSymbolLayers(string StateLayer)
        {
            if (StateLayer == "ctycu")
            {
                string ctycuShapeFilePatten = dataFolder + "\\" + StateLayer + "\\??" + StateLayer + ".shp";
                string ctycuIndexFilePatten = dataFolder + "\\" + StateLayer + "\\ctycu.midx";//"\\??" + StateLayer + ".idx";//"\\ctycu.idx";
                MultipleShapeFileFeatureLayer ctycuLayer = new MultipleShapeFileFeatureLayer(ctycuShapeFilePatten, ctycuIndexFilePatten);

                ctycuLayer.Name = "County";
                ctycuLayer.DrawingQuality = DrawingQuality.HighQuality;
                ctycuLayer.ZoomLevelSet.ZoomLevel11.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 233, 232, 214));
                ctycuLayer.ZoomLevelSet.ZoomLevel11.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                staticLayers.Add(ctycuLayer);
            }
            else
            {
                string ctycuShapeFilePatten = dataFolder + "\\" + StateLayer + "\\??" + StateLayer + ".shp";
                string ctycuIndexFilePatten = dataFolder + "\\" + StateLayer + "\\wat.midx";//"\\??" + StateLayer + ".idx";
                MultipleShapeFileFeatureLayer ctycuLayer = new MultipleShapeFileFeatureLayer(ctycuShapeFilePatten, ctycuIndexFilePatten);

                ctycuLayer.Name = "Lakes/Rivers";
                ctycuLayer.DrawingQuality = DrawingQuality.HighQuality;
                ctycuLayer.ZoomLevelSet.ZoomLevel13.DefaultAreaStyle = AreaStyles.Water2;
                ctycuLayer.ZoomLevelSet.ZoomLevel13.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                staticLayers.Add(ctycuLayer);
            }
        }

        private void LoadStateLabelLayers(string StateLayer)
        {
            if (StateLayer == "wat")
            {
                string ctycuShapeFilePatten = dataFolder + "\\" + StateLayer + "\\??" + StateLayer + ".shp";
                string ctycuIndexFilePatten = dataFolder + "\\" + StateLayer + "\\wat.midx";//"\\??" + StateLayer + ".idx";
                MultipleShapeFileFeatureLayer ctycuLayer = new MultipleShapeFileFeatureLayer(ctycuShapeFilePatten, ctycuIndexFilePatten);

                ctycuLayer.Name = "Lakes/Rivers Label";
                ctycuLayer.ZoomLevelSet.ZoomLevel13.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("LandName", "Arial", 10, DrawingFontStyles.Italic, GeoColor.StandardColors.Navy);
                ctycuLayer.ZoomLevelSet.ZoomLevel13.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
                ctycuLayer.ZoomLevelSet.ZoomLevel13.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
                ctycuLayer.ZoomLevelSet.ZoomLevel13.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;
                dynamicLayers.Add(ctycuLayer);
            }
        }

        //TODO: .midx instead of .idx
        private void LoadLowerRoadSymbolLayers()
        {
            string tlkaShapeFilePatten1 = dataFolder + "\\tlka\\??lkaA71.shp";
            string tlkaIndexFilePatten1 = dataFolder + "\\tlka\\??lkaA71.midx";

            string tlkaShapeFilePatten2 = dataFolder + "\\tlka\\??lkaA70.shp";
            string tlkaIndexFilePatten2 = dataFolder + "\\tlka\\lkaA70.midx";

            string tlkaShapeFilePatten3 = dataFolder + "\\tlka\\??lkaA60.shp";
            string tlkaIndexFilePatten3 = dataFolder + "\\tlka\\lkaA60.midx";

            string tlkaShapeFilePatten4 = dataFolder + "\\tlka\\??lkaA50.shp";
            string tlkaIndexFilePatten4 = dataFolder + "\\tlka\\lkaA50.midx";

            string tlkaShapeFilePatten5 = dataFolder + "\\tlka\\??lkaA40.shp";
            string tlkaIndexFilePatten5 = dataFolder + "\\tlka\\lkaA40.midx";

            string tlkaShapeFilePatten6 = dataFolder + "\\tlka\\??lkaA30.shp";
            string tlkaIndexFilePatten6 = dataFolder + "\\tlka\\lkaA30.midx";

            MultipleShapeFileFeatureLayer lka71Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten1, tlkaIndexFilePatten1);
            MultipleShapeFileFeatureLayer lka70Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten2, tlkaIndexFilePatten2);
            MultipleShapeFileFeatureLayer lka60Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten3, tlkaIndexFilePatten3);
            MultipleShapeFileFeatureLayer lka50Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten4, tlkaIndexFilePatten4);
            MultipleShapeFileFeatureLayer lka40Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten5, tlkaIndexFilePatten5);
            MultipleShapeFileFeatureLayer lka30Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten6, tlkaIndexFilePatten6);

            RenderSymbolLkaA71(ref lka71Layer);
            RenderSymbolLkaA70(ref lka70Layer);
            RenderSymbolLkaA60(ref lka60Layer);
            RenderSymbolLkaA50(ref lka50Layer);
            RenderSymbolLkaA40(ref lka40Layer);
            RenderSymbolLkaA30(ref lka30Layer);
        }

        private void LoadLowerRoadLabelLayers()
        {
            string tlkaShapeFilePatten1 = dataFolder + "\\tlka\\??lkaA71.shp";
            string tlkaIndexFilePatten1 = dataFolder + "\\tlka\\??lkaA71.midx";

            string tlkaShapeFilePatten2 = dataFolder + "\\tlka\\??lkaA70.shp";
            string tlkaIndexFilePatten2 = dataFolder + "\\tlka\\lkaA70.midx";

            string tlkaShapeFilePatten3 = dataFolder + "\\tlka\\??lkaA60.shp";
            string tlkaIndexFilePatten3 = dataFolder + "\\tlka\\lkaA60.midx";

            string tlkaShapeFilePatten4 = dataFolder + "\\tlka\\??lkaA50.shp";
            string tlkaIndexFilePatten4 = dataFolder + "\\tlka\\lkaA50.midx";

            string tlkaShapeFilePatten5 = dataFolder + "\\tlka\\??lkaA40.shp";
            string tlkaIndexFilePatten5 = dataFolder + "\\tlka\\lkaA40.midx";

            string tlkaShapeFilePatten6 = dataFolder + "\\tlka\\??lkaA30.shp";
            string tlkaIndexFilePatten6 = dataFolder + "\\tlka\\lkaA30.midx";

            MultipleShapeFileFeatureLayer lka71Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten1, tlkaIndexFilePatten1);
            MultipleShapeFileFeatureLayer lka70Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten2, tlkaIndexFilePatten2);
            MultipleShapeFileFeatureLayer lka60Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten3, tlkaIndexFilePatten3);
            MultipleShapeFileFeatureLayer lka50Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten4, tlkaIndexFilePatten4);
            MultipleShapeFileFeatureLayer lka40Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten5, tlkaIndexFilePatten5);
            MultipleShapeFileFeatureLayer lka30Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten6, tlkaIndexFilePatten6);

            RenderLabelLkaA71(ref lka71Layer);
            RenderLabelLkaA70(ref lka70Layer);
            RenderLabelLkaA60(ref lka60Layer);
            RenderLabelLkaA50(ref lka50Layer);
            RenderLabelLkaA40(ref lka40Layer);
            RenderLabelLkaA30(ref lka30Layer);
        }

        private void LoadHighRoadSymbolLayers()
        {
            string tlkaShapeFilePatten1 = dataFolder + "\\tlka\\??lkaA10.shp";
            string tlkaIndexFilePatten1 = dataFolder + "\\tlka\\lkaA10.midx";

            string tlkaShapeFilePatten2 = dataFolder + "\\tlka\\??lkaA20.shp";
            string tlkaIndexFilePatten2 = dataFolder + "\\tlka\\lkaA20.midx";

            MultipleShapeFileFeatureLayer lka10Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten1, tlkaIndexFilePatten1);
            RenderSymbolLkaA10(ref lka10Layer);

            MultipleShapeFileFeatureLayer lka20Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten2, tlkaIndexFilePatten2);
            RenderSymbolLkaA20(ref lka20Layer);
        }

        private void LoadHighRoadLabelLayers()
        {
            string tlkaShapeFilePatten1 = dataFolder + "\\tlka\\??lkaA10.shp";
            string tlkaIndexFilePatten1 = dataFolder + "\\tlka\\lkaA10.midx";

            string tlkaShapeFilePatten2 = dataFolder + "\\tlka\\??lkaA20.shp";
            string tlkaIndexFilePatten2 = dataFolder + "\\tlka\\lkaA20.midx";

            MultipleShapeFileFeatureLayer lka10Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten1, tlkaIndexFilePatten1);
            RenderLabelLkaA10(ref lka10Layer);

            MultipleShapeFileFeatureLayer lka20Layer = new MultipleShapeFileFeatureLayer(tlkaShapeFilePatten2, tlkaIndexFilePatten2);
            RenderLabelLkaA20(ref lka20Layer);
        }

        private void RenderSymblLayer(ShapeFileFeatureLayer CurrentLayer)
        {
            string LayerName = Path.GetFileNameWithoutExtension(CurrentLayer.ShapePathFileName);
            switch (LayerName.ToUpperInvariant())
            {
                case "CANADA":
                    RenderSymbolCanada(ref CurrentLayer);
                    break;
                case "MEXICO":
                    RenderSymbolMexico(ref CurrentLayer);
                    break;
                case "CNTRY02_MINUSNA":
                    RenderSymbolCntry02(ref CurrentLayer);
                    break;
                case "STATES":
                    RenderSymbolStates(ref CurrentLayer);
                    break;
                case "COUNTIES":
                    RenderSymbolCounties(ref CurrentLayer);
                    break;
                case "URBAN_DTL":
                    RenderSymbolUrban_dtl(ref CurrentLayer);
                    break;
                case "FEDLANDBIA":
                    RenderSymbolFedlandBIA(ref CurrentLayer);
                    break;
                case "FEDLANDFS":
                    RenderSymbolFedlandFS(ref CurrentLayer);
                    break;
                case "FEDLANDFWS":
                    RenderSymbolFedlandFWS(ref CurrentLayer);
                    break;
                case "FEDLANDDOD":
                    RenderSymbolFedlandDOD(ref CurrentLayer);
                    break;
                case "INTERIORLAKESGEN":
                    RenderSymbolInteriorLakesGen(ref CurrentLayer);
                    break;
                case "INTERIORLAKES":
                    RenderSymbolInteriorLakes(ref CurrentLayer);
                    break;
                case "LAKES":
                    RenderSymbolLakes(ref CurrentLayer);
                    break;
                case "COUNTRYLAKES":
                    RenderSymbolCountryLakes(ref CurrentLayer);
                    break;
                case "FEDLANDNPS":
                    RenderSymbolFedlandNPS(ref CurrentLayer);
                    break;
                case "FEDLANDNPSCLIP":
                    RenderSymbolFedlandNPSclip(ref CurrentLayer);
                    break;
                case "SWAMPS":
                    RenderSymbolSwamps(ref CurrentLayer);
                    break;
                case "RIVERS":
                    RenderSymbolRivers(ref CurrentLayer);
                    break;
                case "RAIL100K":
                    RenderSymbolRail100k(ref CurrentLayer);
                    break;
                case "USHIGH1":
                    RenderSymbolUSHigh1(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK2_1B":
                    RenderSymbolHighWayNetwork2_1b(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK2_2":
                    RenderSymbolHighWayNetwork2_2(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK1_50M":
                    RenderSymbolHighWayNetwork1_50m(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK1_10M":
                    RenderSymbolHighWayNetwork1_10m(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK1":
                    RenderSymbolHighWayNetwork1(ref CurrentLayer);
                    break;
                case "INTERNATIONALBORDERS":
                    RenderSymbolInternationalBorders(ref CurrentLayer);
                    break;
                case "STATEBORDERS":
                    RenderSymbolStateBorders(ref CurrentLayer);
                    break;
                case "PRIMARYBORDERS":
                    RenderSymbolPrimaryBorders(ref CurrentLayer);
                    break;
                case "CITIES_A":
                    RenderSymbolCities_a(ref CurrentLayer);
                    break;
                case "COUNTRYCITIES":
                    RenderSymbolCountryCities(ref CurrentLayer);
                    break;
                case "CITIES_B":
                    RenderSymbolCities_b(ref CurrentLayer);
                    break;
                case "CITIES_C2":
                    RenderSymbolCities_c2(ref CurrentLayer);
                    break;
                case "AIRPORTS":
                    RenderSymbolAirports(ref CurrentLayer);
                    break;
                default:
                    throw new ArgumentException("No Rendering Logic", "CurrentLayer");
            }
        }

        private void RenderLabelLayer(ShapeFileFeatureLayer CurrentLayer)
        {
            string LayerName = Path.GetFileNameWithoutExtension(CurrentLayer.ShapePathFileName);
            switch (LayerName.ToUpperInvariant())
            {
                case "COUNTRYTEXT":
                    RenderLabelCountryText(ref CurrentLayer);
                    break;
                case "SEATEXT":
                    RenderLabelSeaText(ref CurrentLayer);
                    break;
                case "STATETEXT":
                    RenderLabelStateText(ref CurrentLayer);
                    break;
                case "FEDLANDDOD":
                    RenderLabelFedlandDOD(ref CurrentLayer);
                    break;
                case "FEDLANDBIA":
                    RenderLabelFedlandBIA(ref CurrentLayer);
                    break;
                case "FEDLANDFS":
                    RenderLabelFedlandFS(ref CurrentLayer);
                    break;
                case "FEDLANDFWS":
                    RenderLabelFedlandFWS(ref CurrentLayer);
                    break;
                case "FEDLANDNPSCLIP":
                    RenderLabelFedlandNPSclip(ref CurrentLayer);
                    break;
                case "LAKES":
                    RenderLabelLakes(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK1_50M":
                    RenderLabelHighWayNetwork1_50m(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK1_10M":
                    RenderLabelHighWayNetwork1_10m(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK1":
                    RenderLabelHighWayNetwork1(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK2_1B":
                    RenderLabelHighWayNetwork2_1b(ref CurrentLayer);
                    break;
                case "HIGHWAYNETWORK2_2":
                    RenderLabelHighWayNetwork2_2(ref CurrentLayer);
                    break;
                case "USHIGH1":
                    RenderLabelUSHigh1(ref CurrentLayer);
                    break;
                case "COUNTRYCITIES":
                    RenderLabelCountryCities(ref CurrentLayer);
                    break;
                case "CITIES_A":
                    RenderLabelCities_a(ref CurrentLayer);
                    break;
                case "CITIES_B":
                    RenderLabelCities_b(ref CurrentLayer);
                    break;
                case "CITIES_C2":
                    RenderLabelCities_c2(ref CurrentLayer);
                    break;
                case "CITIES_C":
                    RenderLabelCities_c(ref CurrentLayer);
                    break;
                case "CITIES_D":
                    RenderLabelCities_d(ref CurrentLayer);
                    break;
                case "CITIES_E":
                    RenderLabelCities_e(ref CurrentLayer);
                    break;
                case "AIRPORTS":
                    RenderLabelAirports(ref CurrentLayer);
                    break;
                case "LKAA65":
                    RenderLabelLkaA65(ref CurrentLayer);
                    break;
                case "CNTRY02_MINUSNA":
                    RenderLabelCntry02(ref CurrentLayer);
                    break;
                    
                //case "LPT10":
                //    RenderLptD10(ref CurrentLayer);
                //    break;
                //case "LPT20":
                //    RenderLptD20(ref CurrentLayer);
                //    break;
                //case "LPT30":
                //    RenderLptD30(ref CurrentLayer);
                //    break;
                //case "LPT40":
                //    RenderLptD40(ref CurrentLayer);
                //    break;
                //case "LPT50":
                //    RenderLptD50(ref CurrentLayer);
                //    break;
                //case "LPT60":
                //    RenderLptD60(ref CurrentLayer);
                //    break;
                //case "LPT70":
                //    RenderLptD70(ref CurrentLayer);
                //    break;
                //case "LPT80":
                //    RenderLptD80(ref CurrentLayer);
                //    break;
                //case "LPT90":
                //    RenderLptD90(ref CurrentLayer);
                //    break;
                //case "GCHURCH":
                //    RenderChurch(ref CurrentLayer);
                //    break;
                //case "GGOLF":
                //    RenderGolf(ref CurrentLayer);
                //    break;
                //case "GHOSPITL":
                //    RenderHospital(ref CurrentLayer);
                //    break;
                default:
                    throw new ArgumentException("No Rendering Logic", "CurrentLayer");
            }
        }

        #endregion

        #region Render BackGround

        private void RenderSymbolCanada(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Canada";

            Layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 242, 239, 233));
            Layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolMexico(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Mexico";

            Layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 242, 239, 233));
            Layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolCntry02(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Cntry02";

            Layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 242, 239, 233));
            Layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelCntry02(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Cntry02 Label";

            Layer.ZoomLevelSet.ZoomLevel02.CustomStyles.Add(GetStateNameClassBreakStyle());
            Layer.ZoomLevelSet.ZoomLevel02.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(Layer);
        }

        private void RenderLabelSeaText(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Sea Text";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arail", 8, DrawingFontStyles.Italic, GeoColor.FromArgb(255, 80, 120, 160));
            labelLayer.ZoomLevelSet.ZoomLevel02.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;
            labelLayer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderLabelCountryText(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Country Name";

            Layer.DrawingQuality = DrawingQuality.CanvasSettings;

            Layer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arail", 8, DrawingFontStyles.Bold, GeoColor.FromArgb(255, 91, 91, 91));
            Layer.ZoomLevelSet.ZoomLevel02.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;
            Layer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            Layer.ZoomLevelSet.ZoomLevel02.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            dynamicLayers.Add(Layer);
        }

        #endregion

        #region Render Physical Features

        private void RenderSymbolLakes(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Lakes";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultAreaStyle = AreaStyles.Water2;
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLakes(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Lakes Label";
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Italic, GeoColor.FromArgb(255, 80, 120, 160));
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel11.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolCountryLakes(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "CountryLakes";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel03.DefaultAreaStyle = AreaStyles.Water2;
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolInteriorLakesGen(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "InteriorLakesGen";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel03.DefaultAreaStyle = AreaStyles.Water2;
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level07;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolInteriorLakes(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "InteriorLakes";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel08.DefaultAreaStyle = AreaStyles.Water2;
            Layer.ZoomLevelSet.ZoomLevel08.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolSwamps(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Swamps";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultAreaStyle = AreaStyles.Swamp1;
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        //private void RenderWat(ref MultipleShapeFileFeatureLayer Layer)
        //{
        //    Layer.Name = "Lakes/Rivers";

        //    Layer.DrawingQuality = DrawingQuality.HighQuality;

        //    Layer.ZoomLevelSet.ZoomLevel13.DefaultAreaStyle = AreaStyles.Water2;
        //    Layer.ZoomLevelSet.ZoomLevel13.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

        //    MultipleShapeFileFeatureLayer labelLayer = new MultipleShapeFileFeatureLayer(Layer.MultipleShapeFilePattern, Layer.IndexFilePattern);
        //    labelLayer.Name = Layer.Name + " Label";
        //    labelLayer.ZoomLevelSet.ZoomLevel13.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("LandName", "Arial", 10, DrawingFontStyles.Italic, GeoColor.StandardColors.Navy);
        //    labelLayer.ZoomLevelSet.ZoomLevel13.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
        //    labelLayer.ZoomLevelSet.ZoomLevel13.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

        //    Layer.ZoomLevelSet.ZoomLevel16.DefaultAreaStyle = AreaStyles.Water2;
        //    Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

        //    staticLayers.Add(Layer);
        //    dynamicLayers.Add(labelLayer);
        //}

        private void RenderSymbolRivers(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Rivers";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultLineStyle = LineStyles.River2;
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            staticLayers.Add(Layer);
        }

        #endregion

        #region Render Artifical Features

        private void Renderctycu(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "County";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel11.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 233, 232, 214));
            Layer.ZoomLevelSet.ZoomLevel11.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolFedlandBIA(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Bureau Of Indian Affairs";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, GeoColor.StandardColors.LightCoral));
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, GeoColor.StandardColors.LightCoral));
            Layer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelFedlandBIA(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Bureau Of Indian Affairs Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name1", "Arial", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Red, GeoColor.StandardColors.White, 0.5F);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolFedlandFS(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Forest Service";
            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel07.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, 204, 213, 170));
            Layer.ZoomLevelSet.ZoomLevel07.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, 204, 213, 170));
            Layer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelFedlandFS(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Forest Service Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name1", "Arial", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Green, GeoColor.StandardColors.White, 0.5F);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }


        private void RenderSymbolFedlandFWS(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Fish and Wild Life Service";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, 170, 213, 191));
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(150, 170, 213, 191));
            Layer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelFedlandFWS(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Fish and Wild Life Service Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name1", "Arial", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5F);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolFedlandNPS(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "National Park Service ";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel03.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 167, 204, 149));
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolFedlandNPSclip(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "National Park Service";

            Layer.DrawingQuality = DrawingQuality.HighSpeed;

            Layer.ZoomLevelSet.ZoomLevel10.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 167, 204, 149));
            Layer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 167, 204, 149));
            Layer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelFedlandNPSclip(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "National Park Service Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name1", "Arial", 10, DrawingFontStyles.Italic, GeoColor.StandardColors.DarkGreen);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolFedlandDOD(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Department Of Defense";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(200, GeoColor.StandardColors.DarkGray));
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(200, GeoColor.StandardColors.DarkGray));
            Layer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelFedlandDOD(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Department Of Defense Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name1", "Arial", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5F);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolRail100k(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Railroads";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel15.DefaultLineStyle = LineStyles.Railway2;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.Railway1;
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolAirports(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Airports";

            Layer.DrawingQuality = DrawingQuality.CanvasSettings;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultPointStyle.PointType = PointType.Bitmap;
            Layer.ZoomLevelSet.ZoomLevel09.DefaultPointStyle.Image = new GeoImage(dataFolder + @"\Images\airport.png");
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelAirports(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Airports Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle = TextStyles.CreateMaskTextStyle("Name", new GeoFont("Arial", 8, DrawingFontStyles.Regular),new GeoSolidBrush(GeoColor.StandardColors.Black), new AreaStyle(new GeoPen(GeoColor.SimpleColors.Transparent,1.6f), new GeoSolidBrush(GeoColor.FromArgb(255, 242, 236, 223))), 10, 0);
            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle.PointPlacement = PointPlacement.UpperRight;
            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolStateBorders(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "State Borders";

            Layer.ZoomLevelSet.ZoomLevel03.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 156, 155, 154), 1, LineDashStyle.Dash, false);
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolPrimaryBorders(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "PrimaryBorders";

            Layer.ZoomLevelSet.ZoomLevel03.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 156, 155, 154), 0.5F, LineDashStyle.Dash, false);
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolInternationalBorders(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "International Borders";

            Layer.ZoomLevelSet.ZoomLevel03.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 156, 155, 154), 1.5F, LineDashStyle.Solid, false);
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level08;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolCounties(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Counties";

            Layer.ZoomLevelSet.ZoomLevel08.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 233, 232, 214));
            Layer.ZoomLevelSet.ZoomLevel08.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolUrban_dtl(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Detailed Urban Areas";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(200, GeoColor.StandardColors.LightGray));
            Layer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level13;

            staticLayers.Add(Layer);
        }

        private void RenderSymbolStates(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "States";

            Layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 233, 232, 214));
            Layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            staticLayers.Add(Layer);
        }

        private void RenderLabelStateText(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "State Name";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel04.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Abrv", "Arial", 7, DrawingFontStyles.Bold, GeoColor.FromArgb(255, 91, 91, 91));
            labelLayer.ZoomLevelSet.ZoomLevel04.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel04.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel04.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;

            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Bold, GeoColor.FromArgb(255, 91, 91, 91));
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel05.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;

            //labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Bold, GeoColor.FromArgb(255, 91, 91, 91));
            //labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            //labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            //labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            //labelLayer.ZoomLevelSet.ZoomLevel07.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;

            dynamicLayers.Add(labelLayer);
        }

        #endregion

        #region Render Roads

        private void RenderSymbolUSHigh1(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "US Highway";

            Layer.DrawingQuality = DrawingQuality.CanvasSettings;

            LineStyle lineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 1.75f, GeoColor.StandardColors.DarkGray, 1.75f, true);
            Layer.ZoomLevelSet.ZoomLevel06.DefaultLineStyle = lineStyle;
            Layer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level07;

            staticLayers.Add(Layer);
        }

        private void RenderLabelUSHigh1(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.DrawingQuality = DrawingQuality.HighSpeed;
            labelLayer.Name = "US Highway Label";
            labelLayer.ZoomLevelSet.ZoomLevel07.CustomStyles.Add(GetRoadIconStyleForUSHigh1());

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA10(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Highways (10)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;
            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 10, GeoColor.StandardColors.DarkGray, 13, true);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA10(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Highways (10) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;
            
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = GetHighwayIconStyle();
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.OneDuplicateLabelPerQuadrant;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA20(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Major Roads (20)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 255, 255, 128), 9, GeoColor.StandardColors.LightGray, 12, true);
            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 255, 255, 128), 12, GeoColor.StandardColors.LightGray, 15, true);
            Layer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA20(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Major Roads (20) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 9, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 9, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA30(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Secondary Roads (30)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 255, 255, 185), 8, GeoColor.StandardColors.LightGray, 11, true);
            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 255, 255, 185), 11, GeoColor.StandardColors.LightGray, 14, true);

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA30(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Secondary Roads (30) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 9, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.GridSize = 60;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 9, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA40(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Local Roads (40)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel14.DefaultLineStyle = LineStyles.LocalRoad4;
            Layer.ZoomLevelSet.ZoomLevel15.DefaultLineStyle = LineStyles.LocalRoad3;
            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.LocalRoad2;

            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.LocalRoad1;
            Layer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA40(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Local Roads (40) Label";

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 7.5f, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.GridSize = 60;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.GridSize = 125;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA50(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Vehicular Trail (50)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel15.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 2, GeoColor.StandardColors.DarkGray, 4, true);
            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 8, GeoColor.StandardColors.DarkGray, 10, true);
            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 9, GeoColor.StandardColors.DarkGray, 12, true);

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA50(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Vehicular Trail (50) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 7.5f, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.GridSize = 60;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.GridSize = 125;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA60(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Special Roads (60)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 8, GeoColor.StandardColors.DarkGray, 10, true);
            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 9, GeoColor.StandardColors.DarkGray, 12, true);
            Layer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA60(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Special Roads (60) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 7.5f, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.GridSize = 60;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.GridSize = 125;
            labelLayer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA65(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Ferry Crossings (65)";


            Layer.ZoomLevelSet.ZoomLevel14.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 170, 164, 154), 1, true);
            Layer.ZoomLevelSet.ZoomLevel14.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Brown, 12, true);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA65(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Ferry Crossings (65) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 9, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.TextLineSegmentRatio = 1;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA70(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Other Roads (70)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 8, GeoColor.StandardColors.DarkGray, 10, true);
            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.White, 9, GeoColor.StandardColors.DarkGray, 12, true);
            Layer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA70(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Other Roads (70) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 7.5f, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.GridSize = 60;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 2;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.GridSize = 125;
            labelLayer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolLkaA71(ref MultipleShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Pedestrian Way (71)";

            Layer.DrawingQuality = DrawingQuality.HighQuality;
            Layer.ZoomLevelSet.ZoomLevel17.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.LightGray, 5, GeoColor.StandardColors.DarkGray, 7, true);
            Layer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelLkaA71(ref MultipleShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Pedestrian Way (71) Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("[fedirp] [fename] [fetype] [fedirs]", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.TextLineSegmentRatio = 1;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel17.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel17.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolHighWayNetwork1(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Interstates";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel12.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 4, GeoColor.StandardColors.DarkGray, 7, true);
            Layer.ZoomLevelSet.ZoomLevel13.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 6, GeoColor.StandardColors.DarkGray, 9, true);
            Layer.ZoomLevelSet.ZoomLevel13.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level14;
            Layer.ZoomLevelSet.ZoomLevel15.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 8, GeoColor.StandardColors.DarkGray, 11, true);

            staticLayers.Add(Layer);
        }

        private void RenderLabelHighWayNetwork1(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Interstates Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.CustomStyles.Add(GetRoadIconStyle(GeoColor.StandardColors.White));
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolHighWayNetwork1_50m(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Interstates";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel08.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 2.5f, GeoColor.StandardColors.DarkGray, 4.5f, true);

            staticLayers.Add(Layer);
        }

        private void RenderLabelHighWayNetwork1_50m(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Interstates Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel08.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel08.CustomStyles.Add(GetRoadIconStyle(GeoColor.StandardColors.White));

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolHighWayNetwork1_10m(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Interstates";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel09.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 216, 171, 33), 3.5f, GeoColor.StandardColors.DarkGray, 5.5f, true);
            Layer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            staticLayers.Add(Layer);
        }

        private void RenderLabelHighWayNetwork1_10m(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Interstates Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel09.CustomStyles.Add(GetRoadIconStyle(GeoColor.StandardColors.White));
            labelLayer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolHighWayNetwork2_1b(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Primary Roads";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 2, GeoColor.StandardColors.DarkGray, 4, true);
            Layer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;

            Layer.ZoomLevelSet.ZoomLevel13.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 3, GeoColor.StandardColors.DarkGray, 6, true);
            Layer.ZoomLevelSet.ZoomLevel14.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 5, GeoColor.StandardColors.DarkGray, 8, true);
            Layer.ZoomLevelSet.ZoomLevel15.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 8, GeoColor.StandardColors.DarkGray, 11, true);

            staticLayers.Add(Layer);
        }

        private void RenderLabelHighWayNetwork2_1b(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Primary Roads Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel10.CustomStyles.Add(GetRoadIconStyle(GeoColor.StandardColors.Black));
            labelLayer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level13;

            labelLayer.ZoomLevelSet.ZoomLevel14.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("LNAME", "Arial", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel14.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel14.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            labelLayer.ZoomLevelSet.ZoomLevel15.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("LNAME", "Arial", 7, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel15.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel15.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolHighWayNetwork2_2(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Primary Roads";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel10.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 1, GeoColor.StandardColors.DarkGray, 3, true);
            Layer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level12;

            Layer.ZoomLevelSet.ZoomLevel13.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 2, GeoColor.StandardColors.DarkGray, 5, true);
            Layer.ZoomLevelSet.ZoomLevel14.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 5, GeoColor.StandardColors.DarkGray, 8, true);
            Layer.ZoomLevelSet.ZoomLevel15.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.FromArgb(255, 239, 232, 119), 7, GeoColor.StandardColors.DarkGray, 10, true);

            staticLayers.Add(Layer);
        }

        private void RenderLabelHighWayNetwork2_2(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Primary Roads Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel12.CustomStyles.Add(GetRoadIconStyle(GeoColor.StandardColors.Black));
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level13;

            labelLayer.ZoomLevelSet.ZoomLevel14.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("LNAME", "Arial", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel14.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel14.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            labelLayer.ZoomLevelSet.ZoomLevel15.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("LNAME", "Arial", 7, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 0, -1);
            labelLayer.ZoomLevelSet.ZoomLevel15.DefaultTextStyle.TextLineSegmentRatio = 10;
            labelLayer.ZoomLevelSet.ZoomLevel15.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            dynamicLayers.Add(labelLayer);
        }

        #endregion

        #region Render Cities

        private void RenderSymbolCountryCities(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "International cities";

            Layer.ZoomLevelSet.ZoomLevel03.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 216, 95, 95), 4, GeoColor.StandardColors.Black, 1);
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level05;

            Layer.ZoomLevelSet.ZoomLevel06.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 216, 95, 95), 6, GeoColor.StandardColors.Black, 1);
            Layer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
        }

        private void RenderLabelCountryCities(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "International cities Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("city_name", "Arial", 10, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, -8, -7);
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.PointPlacement = PointPlacement.CenterRight;
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.BestPlacement = false;
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level04;

            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("city_name", "Arial", 11, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, -8, -7);
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.PointPlacement = PointPlacement.CenterRight;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.BestPlacement = false;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel05.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolCities_a(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Major cities";

            Layer.ZoomLevelSet.ZoomLevel03.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 216, 95, 95), 4, GeoColor.StandardColors.Black, 1);
            Layer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level05;

            Layer.ZoomLevelSet.ZoomLevel06.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 216, 95, 95), 6, GeoColor.StandardColors.Black, 1);

            Layer.ZoomLevelSet.ZoomLevel07.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 216, 95, 95), 6, GeoColor.StandardColors.Black, 2);
            Layer.ZoomLevelSet.ZoomLevel07.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            staticLayers.Add(Layer);
        }

        private void RenderLabelCities_a(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Major cities Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 10, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, -8, -7);
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.PointPlacement = PointPlacement.CenterRight;
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.BestPlacement = false;
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel03.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel03.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level04;

            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 11, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, -8, -7);
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.PointPlacement = PointPlacement.CenterRight;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.BestPlacement = false;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel05.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level06;

            labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 13, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, -10, -10);
            labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.PointPlacement = PointPlacement.CenterRight;
            labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel07.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel07.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 14, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, 0, 0);
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 16, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.25f, 0, 0);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.DuplicateRule = LabelDuplicateRule.NoDuplicateLabels;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level13;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolCities_b(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Medium cities";

            Layer.ZoomLevelSet.ZoomLevel06.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 216, 95, 95), 5, GeoColor.StandardColors.Black, 1);
            Layer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            staticLayers.Add(Layer);
        }

        private void RenderLabelCities_b(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Medium cities Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel06.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 10, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.25f, -10, -8);
            labelLayer.ZoomLevelSet.ZoomLevel06.DefaultTextStyle.PointPlacement = PointPlacement.CenterRight;
            labelLayer.ZoomLevelSet.ZoomLevel06.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level09;

            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 12, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.25f, 0, 0);
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel10.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level11;

            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 12, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.25f, 0, 0);
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel12.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel12.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level13;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderSymbolCities_c2(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Small Cities";

            Layer.ZoomLevelSet.ZoomLevel08.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(255, 226, 147, 147), 4, GeoColor.StandardColors.Black);

            staticLayers.Add(Layer);
        }

        private void RenderLabelCities_c2(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Small Cities Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel08.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 10, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2.5f, -5, 3);
            labelLayer.ZoomLevelSet.ZoomLevel08.DefaultTextStyle.PointPlacement = PointPlacement.UpperRight;
            labelLayer.ZoomLevelSet.ZoomLevel08.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderLabelCities_c(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Small Cities Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 10, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2.5f, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("areaname", "Arial", 11, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 2.5f, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel11.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderLabelCities_d(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Towns Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("name", "Arial", 9, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel09.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel09.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("name", "Arial", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel11.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

            dynamicLayers.Add(labelLayer);
        }

        private void RenderLabelCities_e(ref ShapeFileFeatureLayer labelLayer)
        {
            labelLayer.Name = "Small Towns Label";

            labelLayer.DrawingQuality = DrawingQuality.CanvasSettings;

            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("name", "Arial", 8, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel10.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("name", "Arial", 9, DrawingFontStyles.Bold, GeoColor.StandardColors.Black, GeoColor.StandardColors.White, 0.5f, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.PointPlacement = PointPlacement.Center;
            labelLayer.ZoomLevelSet.ZoomLevel11.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel11.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level15;

            dynamicLayers.Add(labelLayer);
        }

        #endregion

        #region Render Points Of Interest

        private void RenderLptD10(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Military installation or reservation";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.LightGray, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD20(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Multi-household or Transient Quarters";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Aquamarine, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD30(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Custodial Facility";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Beige, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD40(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Educational or Religious Institution";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Red, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD50(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Transportation Terminal";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.DarkOrange, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD60(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Employment Center";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.DarkSalmon, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD70(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Tower";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.DarkTurquoise, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD80(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Open Space";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.LawnGreen, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderLptD90(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Special Purpose Landmark";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Khaki, 9, GeoColor.StandardColors.DarkGray, 2);
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            Layer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            Layer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderChurch(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Church";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = new PointStyle(new GeoFont("Impact", 12, DrawingFontStyles.Regular), 67, new GeoSolidBrush(GeoColor.StandardColors.Red));
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderGolf(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Golf";

            Layer.DrawingQuality = DrawingQuality.HighQuality;

            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = new PointStyle(new GeoFont("Impact", 12, DrawingFontStyles.Regular), 71, new GeoSolidBrush(GeoColor.StandardColors.DarkGreen));
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            labelLayer.Name = Layer.Name + " Label"; dynamicLayers.Add(labelLayer);
        }

        private void RenderHospital(ref ShapeFileFeatureLayer Layer)
        {
            Layer.Name = "Hospital";

            Layer.DrawingQuality = DrawingQuality.HighQuality;
            Layer.ZoomLevelSet.ZoomLevel16.DefaultPointStyle = new PointStyle(new GeoFont("Impact", 12, DrawingFontStyles.Regular), 72, new GeoSolidBrush(GeoColor.StandardColors.DarkBlue));
            Layer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            ShapeFileFeatureLayer labelLayer = new ShapeFileFeatureLayer(Layer.ShapePathFileName, ShapeFileReadWriteMode.ReadOnly);
            labelLayer.Name = Layer.Name + " Label";
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("Name", "Arial", 8, DrawingFontStyles.Regular, GeoColor.StandardColors.Black, 4, 0);
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.BestPlacement = true;
            labelLayer.ZoomLevelSet.ZoomLevel16.DefaultTextStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            labelLayer.ZoomLevelSet.ZoomLevel16.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticLayers.Add(Layer);
            dynamicLayers.Add(labelLayer);
        }

        #endregion

        #region Assist Methods

        private IconStyle GetHighwayIconStyle()
        {
            string iconImageFile = dataFolder + @"\Images\Interstate_ThinOutline_2.gif";
            IconStyle iconStyle = new IconStyle(iconImageFile, "fename", new GeoFont("Arial", 7, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.StandardColors.White));
            iconStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            iconStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;

            return iconStyle;
        }

        private IconValueStyle GetRoadIconStyle(GeoColor geoColor)
        {
            IconValueStyle iconValueStyle = new IconValueStyle("Signt1");

            IconValueItem item1 = new IconValueItem("I", dataFolder + @"\Images\Interstate_ThinOutline_1.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item1.TextValueLengthMin = 1;
            item1.TextValueLengthMax = 2;

            IconValueItem item2 = new IconValueItem("I", dataFolder + @"\Images\Interstate_ThinOutline_2.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item2.TextValueLengthMin = 3;
            item2.TextValueLengthMax = 4;

            IconValueItem item3 = new IconValueItem("S", dataFolder + @"\Images\state-oval.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item3.TextValueLengthMin = 1;
            item3.TextValueLengthMax = 2;

            IconValueItem item4 = new IconValueItem("S", dataFolder + @"\Images\state-oval-2.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item4.TextValueLengthMin = 3;
            item4.TextValueLengthMax = 5;

            IconValueItem item5 = new IconValueItem("U", dataFolder + @"\Images\ushwy-1.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item5.TextValueLengthMin = 1;
            item5.TextValueLengthMax = 2;

            IconValueItem item6 = new IconValueItem("U", dataFolder + @"\Images\ushwy-2.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item6.TextValueLengthMin = 3;
            item6.TextValueLengthMax = 3;

            IconValueItem item7 = new IconValueItem("U", dataFolder + @"\Images\ushwy-3.gif", new TextStyle("Signn1", new GeoFont("Arial", 8, DrawingFontStyles.Bold), new GeoSolidBrush(geoColor)));
            item7.TextValueLengthMin = 4;
            item7.TextValueLengthMax = 5;

            iconValueStyle.IconValueItems.Add(item1);
            iconValueStyle.IconValueItems.Add(item2);
            iconValueStyle.IconValueItems.Add(item3);
            iconValueStyle.IconValueItems.Add(item4);
            iconValueStyle.IconValueItems.Add(item5);
            iconValueStyle.IconValueItems.Add(item6);
            iconValueStyle.IconValueItems.Add(item7);

            iconValueStyle.GridSize = 200;
            iconValueStyle.TextLineSegmentRatio = 10;
            iconValueStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            iconValueStyle.OverlappingRule = LabelOverlappingRule.AllowOverlapping;

            return iconValueStyle;
        }

        private IconValueStyle GetRoadIconStyleForUSHigh1()
        {
            IconValueStyle iconValueStyle = new IconValueStyle("Admn_class");

            IconValueItem item1 = new IconValueItem("Interstate", dataFolder + @"\Images\Small_Interstate_ThinOutline_1.gif", new TextStyle("Name", new GeoFont("Arial", 7, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.StandardColors.White)));
            item1.TextValueLengthMin = 1;
            item1.TextValueLengthMax = 2;

            IconValueItem item2 = new IconValueItem("Interstate", dataFolder + @"\Images\Small_Interstate_ThinOutline_2.gif", new TextStyle("Name", new GeoFont("Arial", 7, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.StandardColors.White)));
            item2.TextValueLengthMin = 3;
            item2.TextValueLengthMax = 4;

            iconValueStyle.IconValueItems.Add(item1);
            iconValueStyle.IconValueItems.Add(item2);

            iconValueStyle.DuplicateRule = LabelDuplicateRule.UnlimitedDuplicateLabels;
            iconValueStyle.OverlappingRule = LabelOverlappingRule.NoOverlapping;
            iconValueStyle.GridSize = 20;
            return iconValueStyle;
        }

        private ClassBreakStyle GetStateNameClassBreakStyle()
        {
            ClassBreakStyle classBreakStyle = new ClassBreakStyle("SQKM");
            classBreakStyle.ClassBreaks.Add(new ClassBreak(double.MinValue, TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arail", 6, DrawingFontStyles.Regular, GeoColor.StandardColors.Transparent)));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(243300, TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arail", 5, DrawingFontStyles.Regular, GeoColor.FromArgb(255, 91, 91, 91))));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(3000000, TextStyles.CreateSimpleTextStyle("CNTRY_NAME", "Arail", 8, DrawingFontStyles.Bold, GeoColor.FromArgb(255, 91, 91, 91))));

            return classBreakStyle;
        }

        #endregion
    }
}
