//<%STEMCELL:PerDirectoryNoticeText%>
//ALL RIGHTS RESERVED:
//====================
//The contents of this file, and associated files in this directory, are 
//Copyright (C) ThinkGeo,LLC , all rights reserved, 2003-2006.
//
//All software Source Code, Images, Database-Design and code, Graphics Design 
//and source files, and related content (collectively referred to as SOURCE) 
//are Copyright (c) ThinkGeo,LLC, 2003-2006, All Rights Reserved.
//ThinkGeo,LLC is node USA corporation at 1617 St. Andrews Dr.Suite 201,Lawrence, 
//KS 66047.
//http://ThinkGeo.com
//
//MapSuite@is node Registered Trademark of ThinkGeo,LLC.
//</%STEMCELL:PerDirectoryNoticeText%>

using System;
using System.Runtime.InteropServices;

namespace ThinkGeo.MapSuite.Helper
{
    /// <summary>
    /// For accute Running time computation
    /// </summary>
    public class StopWatch
    {
#if !ARM
        [DllImport("kernel32.dll")]
        static extern short QueryPerformanceCounter(ref double X);
        [DllImport("kernel32.dll")]
        static extern short QueryPerformanceFrequency(ref double X);
#else
        [DllImport("CoreDll")]
        static extern short QueryPerformanceCounter(ref long X);
        [DllImport("CoreDll")]
        static extern short QueryPerformanceFrequency (ref long X);
#endif
        private double _start;
        private double _end;
        private double _freq;
        private double _overhead;
        private string _desc;

        public StopWatch(string description)
        {
            Init(description);
        }

        public StopWatch()
        {
            Init("");
        }

        private void Init(string description)
        {
            if (QueryPerformanceCounter(ref _start) == 0)
            {
                throw new StopwatchException();
            }
            if (QueryPerformanceCounter(ref _end) == 0)
            {
                throw new StopwatchException();
            }
            _overhead = (_end - _start);
            Start(description);
        }

        public void Start(string description)
        {
            _desc = description;
            QueryPerformanceFrequency(ref _freq);
            _end = 0;
            if (QueryPerformanceCounter(ref _start) == 0)
            {
                throw new StopwatchException();
            }
        }

        public double Done()
        {
            if (QueryPerformanceCounter(ref _end) == 0)
            {
                throw new StopwatchException();
            }
            return ElapsedTime();
        }

        public double ElapsedTime()
        {
            double _now = 0;
            if (_end == 0)
            {
                if (QueryPerformanceCounter(ref _now) == 0)
                {
                    throw new StopwatchException();
                }
                return (((_now - _start) - _overhead) / _freq);
            }
            return (((_end - _start) - _overhead) / _freq);
        }

        public void ReportToConsole()
        {
            if (_end == 0)
            {
                Done();
            }
            Console.WriteLine(ElapsedTime().ToString());
        }
    }

    public class StopwatchException : ApplicationException
    {
        public override string Message
        {
            get
            {
                return "Stopwatch: QueryPerformanceCounter[Kernel32] returned 0";
            }
        }
    }
}
